# HeidTex

This package aims to aid developers, students and researchers to simplify adding tables and other LaTex elements to their reports and papers.

The package is currently in development and features will follow in the near future.